﻿using System.Collections.Generic;
using System.ServiceModel;
using System.Threading.Tasks;
using NavisionApp.NAVService;

namespace NavisionApp
{
    public class Customer
    {
        public string FirstName { get; set; }

        public string Address { get; set; }

        public string Address2 { get; set; }

        public string City { get; set; }

        public string State { get; set; }

        public string Zipcode { get; set; }

        public string Balance { get; set; }

        public string NAVCustNo { get; set; }

        public string ContactNo { get; set; }

        public string BalanceDue { get; set; }

        public int NoOfOrders { get; set; }

        public int NoOfInvoices { get; set; }

        public string Sales { get; set; }
    }

    public class GetCustomers
    {
        WebServiceHelper webServiceHelper = new WebServiceHelper();

        public List<Customer> LoadCustomers()
        {

            try
            {
                string baseURL = "http://localhost:7047/DynamicsNAV70/WS/CRONUS USA, Inc./Page/CustomerCard";

                CustomerCard_PortClient CustomerCardService = new CustomerCard_PortClient(webServiceHelper.GetNAVBinding(), new EndpointAddress(baseURL));

                CustomerCardService.ClientCredentials.Windows.AllowedImpersonationLevel = System.Security.Principal.TokenImpersonationLevel.Delegation;
                CustomerCardService.ClientCredentials.Windows.ClientCredential.UserName = "win8user";
                CustomerCardService.ClientCredentials.Windows.ClientCredential.Password = "win8win8";
                CustomerCardService.ClientCredentials.Windows.ClientCredential.Domain = "WIN8RTM";


                const int fetchsize = 30;

                Task<ReadMultiple_Result5> _custResult = CustomerCardService.ReadMultipleAsync(new CustomerCard_Filter[] { }, null, fetchsize);
                ReadMultiple_Result5 customerResults = _custResult.Result;

                List<Customer> Customers = new List<Customer>();

                foreach (CustomerCard c in customerResults.ReadMultiple_Result)
                {
                    Customer Cust = new Customer();
                    Cust.FirstName = c.Name;
                    Cust.NAVCustNo = c.No;
                    Cust.Address = c.Address;
                    Cust.Address2 = c.Address_2;
                    Cust.City = c.City;
                    Cust.State = c.County;
                    Cust.Balance = string.Format("{0:C}", System.Convert.ToDecimal(c.Balance_LCY));
                    Cust.BalanceDue = string.Format("{0:C}", System.Convert.ToDecimal(c.Balance_Due));
                    Cust.ContactNo = c.Contact;
                    Cust.Zipcode = c.Post_Code;
                    Cust.Sales = string.Format("{0:C}", System.Convert.ToDecimal(c.Sales_LCY));

                    Customers.Add(Cust);
                }

                return Customers;
            }
            catch (System.Exception)
            {
                
                throw;
            }
            
        }

        public List<Customer> SearchCustomers(string searchString)
        {
            try
            {
                string baseURL = "http://localhost:7047/DynamicsNAV70/WS/CRONUS USA, Inc./Page/CustomerCard";

                CustomerCard_PortClient CustomerCardService = new CustomerCard_PortClient(webServiceHelper.GetNAVBinding(), new EndpointAddress(baseURL));

                CustomerCardService.ClientCredentials.Windows.AllowedImpersonationLevel = System.Security.Principal.TokenImpersonationLevel.Delegation;
                CustomerCardService.ClientCredentials.Windows.ClientCredential.UserName = "win8user";
                CustomerCardService.ClientCredentials.Windows.ClientCredential.Password = "win8win8";
                CustomerCardService.ClientCredentials.Windows.ClientCredential.Domain = "WIN8RTM";


                const int fetchsize = 200;
                CustomerCard_Filter filter1 = new CustomerCard_Filter();
                filter1.Field = CustomerCard_Fields.Name;
                filter1.Criteria = "@*" + searchString + "*";
                CustomerCard_Filter filter2 = new CustomerCard_Filter();
                filter2.Field = CustomerCard_Fields.Location_Code;
                filter2.Criteria = "RED|BLUE";
                CustomerCard_Filter[] filters = new CustomerCard_Filter[] { filter1 };

                Task<ReadMultiple_Result5> _custResult = CustomerCardService.ReadMultipleAsync(filters, null, fetchsize);
                ReadMultiple_Result5 customerResults = _custResult.Result;

                List<Customer> Customers = new List<Customer>();

                foreach (CustomerCard c in customerResults.ReadMultiple_Result)
                {
                    Customer Cust = new Customer();
                    Cust.FirstName = c.Name;
                    Cust.NAVCustNo = c.No;
                    Cust.Address = c.Address;
                    Cust.Address2 = c.Address_2;
                    Cust.City = c.City;
                    Cust.State = c.County;
                    Cust.Balance = string.Format("{0:C}", System.Convert.ToDecimal(c.Balance_LCY));
                    Cust.BalanceDue = string.Format("{0:C}", System.Convert.ToDecimal(c.Balance_Due));
                    Cust.ContactNo = c.Contact;
                    Cust.Zipcode = c.Post_Code;
                    Cust.Sales = string.Format("{0:C}", System.Convert.ToDecimal(c.Sales_LCY));

                    Customers.Add(Cust);
                }

                return Customers;
            }
            catch (System.Exception)
            {
                
                throw;
            }
            
        }
    }
}