﻿using System;
using System.Collections.Generic;
using System.ServiceModel;
using System.Threading.Tasks;
using NavisionApp.NAVService;

namespace NavisionApp
{
    public class PurchHeader
    {
        public string orderNo { get; set; }

        public string vendNo { get; set; }

        public string vendName { get; set; }

        public string vendAddr { get; set; }

        public string vendAddr2 { get; set; }

        public string vendCity { get; set; }

        public string vendState { get; set; }

        public string vendZipcode { get; set; }

        public string vendCountry { get; set; }

        public string vendContactNo { get; set; }

        public string orderDate { get; set; }

        public string orderAmt { get; set; }

        public string vendInvoiceNo { get; set; }

        public string payTerms { get; set; }

        public string status { get; set; }
    }

    public class PurchLine
    {
        public string itemNo { get; set; }

        public string itemDesc { get; set; }

        public string Qty { get; set; }

        public string unitPrice { get; set; }

        public string shipDate { get; set; }

        public string planShipDate { get; set; }

        public string lineAmt { get; set; }

        public string qtyToShip { get; set; }

        public string qtyToInvoice { get; set; }
    }

    public class GetPurchases
    {
        private WebServiceHelper webServiceHelper = new WebServiceHelper();

        public List<PurchHeader> LoadPurchases()
        {
            try
            {
                string baseURL = "http://localhost:7047/DynamicsNAV70/WS/CRONUS USA, Inc./Page/PurchaseOrder";

                PurchaseOrder_PortClient PurchaseOrderService = new PurchaseOrder_PortClient(webServiceHelper.GetNAVBinding(), new EndpointAddress(baseURL));

                PurchaseOrderService.ClientCredentials.Windows.AllowedImpersonationLevel = System.Security.Principal.TokenImpersonationLevel.Delegation;
                PurchaseOrderService.ClientCredentials.Windows.ClientCredential.UserName = "win8user";
                PurchaseOrderService.ClientCredentials.Windows.ClientCredential.Password = "win8win8";
                PurchaseOrderService.ClientCredentials.Windows.ClientCredential.Domain = "WIN8RTM";

                const int fetchsize = 30;

                Task<ReadMultiple_Result3> _purchResult = PurchaseOrderService.ReadMultipleAsync(new PurchaseOrder_Filter[] { }, null, fetchsize);
                ReadMultiple_Result3 purchResults = _purchResult.Result;

                List<PurchHeader> navPurchases = new List<PurchHeader>();
                List<PurchLine> navPurchLines = new List<PurchLine>();

                foreach (PurchaseOrder po in purchResults.ReadMultiple_Result)
                {
                    PurchHeader navPurch = new PurchHeader();
                    navPurch.orderNo = po.No;
                    navPurch.vendNo = po.Buy_from_Vendor_No;
                    navPurch.vendName = po.Buy_from_Vendor_Name;
                    navPurch.vendAddr = po.Buy_from_Address;
                    navPurch.vendAddr2 = po.Buy_from_Address_2;
                    navPurch.vendCity = po.Buy_from_City;
                    navPurch.vendState = po.Buy_from_County;
                    navPurch.vendZipcode = po.Buy_from_Post_Code;
                    navPurch.vendContactNo = po.Buy_from_Contact_No;
                    navPurch.orderDate = po.Order_Date.Date.ToString(); ;
                    navPurch.vendInvoiceNo = po.Vendor_Invoice_No;
                    navPurch.orderAmt = string.Format("{0:C}", System.Convert.ToDecimal(po.Total_Order_Amount));
                    navPurch.status = po.Status.ToString();
                    navPurchases.Add(navPurch);
                }

                return navPurchases;
            }
            catch (Exception)
            {
                throw;
            }
        }

        public List<PurchHeader> SearchPurchases(string searchString)
        {
            try
            {
                string baseURL = "http://localhost:7047/DynamicsNAV70/WS/CRONUS USA, Inc./Page/PurchaseOrder";

                PurchaseOrder_PortClient PurchaseOrderService = new PurchaseOrder_PortClient(webServiceHelper.GetNAVBinding(), new EndpointAddress(baseURL));

                PurchaseOrderService.ClientCredentials.Windows.AllowedImpersonationLevel = System.Security.Principal.TokenImpersonationLevel.Delegation;
                PurchaseOrderService.ClientCredentials.Windows.ClientCredential.UserName = "win8user";
                PurchaseOrderService.ClientCredentials.Windows.ClientCredential.Password = "win8win8";
                PurchaseOrderService.ClientCredentials.Windows.ClientCredential.Domain = "WIN8RTM";

                const int fetchsize = 30;
                PurchaseOrder_Filter filter = new PurchaseOrder_Filter();
                filter.Field = PurchaseOrder_Fields.Buy_from_Vendor_Name;
                filter.Criteria = "@*" + searchString + "*";

                PurchaseOrder_Filter[] filters = new PurchaseOrder_Filter[] { filter };

                Task<ReadMultiple_Result3> _purchResult = PurchaseOrderService.ReadMultipleAsync(filters, null, fetchsize);
                ReadMultiple_Result3 purchResults = _purchResult.Result;

                List<PurchHeader> navPurchases = new List<PurchHeader>();
                List<PurchLine> navPurchLines = new List<PurchLine>();

                foreach (PurchaseOrder po in purchResults.ReadMultiple_Result)
                {
                    PurchHeader navPurch = new PurchHeader();
                    navPurch.orderNo = po.No;
                    navPurch.vendNo = po.Buy_from_Vendor_No;
                    navPurch.vendName = po.Buy_from_Vendor_Name;
                    navPurch.vendAddr = po.Buy_from_Address;
                    navPurch.vendAddr2 = po.Buy_from_Address_2;
                    navPurch.vendCity = po.Buy_from_City;
                    navPurch.vendState = po.Buy_from_County;
                    navPurch.vendZipcode = po.Buy_from_Post_Code;
                    navPurch.vendContactNo = po.Buy_from_Contact_No;
                    navPurch.orderDate = po.Order_Date.Date.ToString(); ;
                    navPurch.vendInvoiceNo = po.Vendor_Invoice_No;
                    navPurch.orderAmt = string.Format("{0:C}", System.Convert.ToDecimal(po.Total_Order_Amount));
                    navPurch.status = po.Status.ToString();
                }

                return navPurchases;
            }
            catch (Exception)
            {
                throw;
            }
        }
    }
}

